Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3519)

Unified Diff: chrome/browser/resources/ntp4/most_visited_page.js

Issue 7810007: [ntp4] More UI refinements (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/ntp4/most_visited_page.js
===================================================================
--- chrome/browser/resources/ntp4/most_visited_page.js (revision 98872)
+++ chrome/browser/resources/ntp4/most_visited_page.js (working copy)
@@ -91,7 +91,7 @@
var faviconDiv = this.querySelector('.favicon');
var faviconUrl = data.faviconUrl ||
- 'chrome://favicon/size/32/' + data.url;
+ 'chrome://favicon/size/16/' + data.url;
faviconDiv.style.backgroundImage = url(faviconUrl);
faviconDiv.dir = data.direction;
if (data.faviconDominantColor) {
@@ -259,8 +259,8 @@
* @return {number} The height.
*/
function heightForWidth(width) {
- // The 2s are for borders, the 23 is for the title.
- return (width - 2) * 132 / 212 + 2 + 23;
+ // The 2s are for borders, the 31 is for the title.
+ return (width - 2) * 132 / 212 + 2 + 31;
}
var THUMBNAIL_COUNT = 8;
« no previous file with comments | « chrome/browser/resources/ntp4/most_visited_page.css ('k') | chrome/browser/ui/webui/ntp/favicon_webui_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698